@@ -1,24 +1,26 @@
 """Helpers for CLI Interface."""
+
 from __future__ import annotations
 
 import re
 from argparse import ArgumentTypeError
 from collections import defaultdict
-from collections.abc import Generator
 from functools import partial
-from typing import TYPE_CHECKING, Callable
+from typing import TYPE_CHECKING
 
-from ..consts import MAC_ADDRESS_REGEX
-from ..data import Change
-from ..formatting import format_led_colour, format_liquid_level, format_temp
+from ember_mug.consts import MAC_ADDRESS_REGEX
+from ember_mug.data import Change
+from ember_mug.formatting import format_led_colour, format_liquid_level, format_temp
 
 if TYPE_CHECKING:
-    from ..mug import EmberMug
+    from collections.abc import Callable, Generator
+
+    from ember_mug.mug import EmberMug
 
 
 base_formatters: dict[str, Callable] = {
-    'led_colour': format_led_colour,
-    'liquid_level': format_liquid_level,
+    "led_colour": format_led_colour,
+    "liquid_level": format_liquid_level,
 }
 
 
@@ -31,9 +33,9 @@ def validate_mac(value: str) -> str:
 
 def build_sub_rows(row: tuple[str, ...]) -> dict[int, dict[int, str]]:
     """Build a defaultdict of cells to pad for empty values."""
-    sub_rows: dict[int, dict[int, str]] = defaultdict(lambda: defaultdict(lambda: ''))
+    sub_rows: dict[int, dict[int, str]] = defaultdict(lambda: defaultdict(lambda: ""))
     for i, col in enumerate(row):
-        for j, val in enumerate(str(col).split(', ')):
+        for j, val in enumerate(str(col).split(", ")):
             sub_rows[j][i] = val
     return sub_rows
 
@@ -49,27 +51,27 @@ def print_table(data: list[tuple[str, ...]]) -> None:
     print(vertical)
     for row in rows:
         for sub_row in row.values():
-            inner = '|'.join(f' {sub_row[i]:<{width-2}} ' for i, width in enumerate(column_sizes))
-            print(f'|{inner}|')
+            inner = "|".join(f" {sub_row[i]:<{width-2}} " for i, width in enumerate(column_sizes))
+            print(f"|{inner}|")
         print(vertical)
 
 
 def print_info(mug: EmberMug) -> None:
     """Print all mug data."""
-    print('Mug Data')
-    print_table([(k, v) for (k, v) in mug.formatted_data.items()])
+    print("Device Data")
+    print_table(list(mug.data.formatted.items()))
 
 
 def print_changes(changes: list[Change], metric: bool = True) -> None:
     """Print changes."""
     formatters: dict[str, Callable] = {
-        'current_temp': partial(format_temp, metric=metric),
-        'target_temp': partial(format_temp, metric=metric),
+        "current_temp": partial(format_temp, metric=metric),
+        "target_temp": partial(format_temp, metric=metric),
         **base_formatters,
     }
     for attr, old_value, new_value in changes:
         if formatter := formatters.get(attr):
-            old_value, new_value = formatter(old_value), formatter(new_value)
+            old_value, new_value = formatter(old_value), formatter(new_value)  # noqa: PLW2901
         print(Change(attr, old_value, new_value))
 
 
